@@ -11,7 +11,7 @@ bh=max(c(r[u<=(r/n)*alpha],0),na.rm = T)
 
 su<-sort(u)
 jj<-which(u==1)
-if(length(jj)!=0) pi0<-(-1/n)*sum(log(1-u[-jj])) else pi0<-(-1/n)*sum(log(1-u))
+if(length(jj)!=0) pi0<-1 else pi0<-min((-1/n)*sum(log(1-u)),1)
 
 if(bh==0){FDR_BH<-0}else{FDR_BH<-round((pi0*su[bh])/(ecdf(u)(su[bh])),4)}
 
@@ -24,7 +24,7 @@ ad.p[i]<-min(sort(u)[i]*(n/i),ad.p[i+1])
 }
 
 
-return(c(list(Rejections=bh,FDR=FDR_BH,Adjusted.pvalues=sort(ad.p))))
+return(c(list(Rejections=bh,FDR=min(FDR_BH,1),Adjusted.pvalues=sort(ad.p))))
 }
 
 if(missing(u)){stop("data argument is required")}
